@@ -1,7 +1,8 @@
 from logging import getLogger
+from os import PathLike
 from os.path import exists
 from threading import Thread, Event
-from typing import Callable, List
+from typing import Callable, List, Union
 
 try:
     import git
@@ -14,8 +15,8 @@ logger = getLogger(__name__)
 
 class GitMonitor(object):
     """ A Git monitor to detect changes in a branch. """
-    def __init__(self, func: Callable, folder: str, repository: str, branch: str = None, force: bool = False,
-                 interval: int = 0) -> None:
+    def __init__(self, func: Callable, folder: Union[str, PathLike, bytes], repository: str, branch: str = None,
+                 force: bool = False, interval: int = 0) -> None:
         """ Monitor a chatbot data repository.
         :param func: The function to call when the repository changes or
           the first time if the force argument is activated.
@@ -36,6 +37,7 @@ class GitMonitor(object):
         self.__stop = False
         self.__thread = None
         self.__event = Event()
+        self.repo = git.Repo(self.folder) if exists(self.folder) else git.Repo.clone_from(self.repository, self.folder)
 
     def monitor(self, update: bool = True, **kwargs) -> None:
         """ Start the monitor.
@@ -43,27 +45,24 @@ class GitMonitor(object):
         :param kwargs: Extra arguments to pass to the function.
         """
         force = self.force
-        if exists(self.folder):
-            repo = git.Repo(self.folder)
-        else:
-            force = True
-            repo = git.Repo.clone_from(self.repository, self.folder)
         if not self.branch:
-            self.branch = repo.active_branch.name
-        elif repo.active_branch.name != self.branch:
-            repo.git.checkout(self.branch)
+            self.branch = self.repo.active_branch.name
+        elif self.repo.active_branch.name != self.branch:
+            self.repo.git.checkout(self.branch)
         updated = True
         while not self.__stop:
-            changes = self.__changes(repo)
+            changes = self.__changes(self.repo)
             if changes or force:
                 if update:
-                    repo.git.pull()
+                    self.repo.git.pull()
                     updated = True
                 self.func(*changes, **kwargs)
             if not self.interval:
                 break
             if updated:
-                logger.info(f'Waiting {self.interval}s for changes in the configuration. ')
+                logger.info(f'Update function executed, waiting {self.interval}s for changes in the repository. ')
+            else:
+                logger.info(f'No changes detected, waiting {self.interval}s for changes in the repository. ')
             self.__event.wait(self.interval)
             force = False
             updated = False
